from explay.exp import main


if __name__ == "__main__":
    ee = main()
